@@ -333,6 +333,10 @@ class Dominus:
         from .namespaces.portal import PortalNamespace
         self.portal = PortalNamespace(self)
 
+        # Initialize FastAPI namespace (decorators for route auth)
+        from .namespaces.fastapi import FastAPINamespace
+        self.fastapi = FastAPINamespace(self)
+
         # Cache for JWT public key
         self._public_key_cache = None
 
